# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.115
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from helix_platform_api_public_client.api.transmission_right_api import TransmissionRightApi  # noqa: E501


class TestTransmissionRightApi(unittest.TestCase):
    """TransmissionRightApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TransmissionRightApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_get_transmission_rights_overview(self) -> None:
        """Test case for get_transmission_rights_overview

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.115
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist

class BusinessProcessForkBlock(BaseModel):
    """
    BusinessProcessForkBlock
    """
    block_type: StrictStr = Field(..., alias="blockType")
    blocks: conlist(conlist(BusinessProcessContentBlock)) = Field(...)
    __properties = ["blockType", "blocks"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BusinessProcessForkBlock:
        """Create an instance of BusinessProcessForkBlock from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in blocks (list of list)
        _items = []
        if self.blocks:
            for _item in self.blocks:
                if _item:
                    _items.append(
                         [_inner_item.to_dict() for _inner_item in _item if _inner_item is not None]
                    )
            _dict['blocks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BusinessProcessForkBlock:
        """Create an instance of BusinessProcessForkBlock from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BusinessProcessForkBlock.parse_obj(obj)

        _obj = BusinessProcessForkBlock.parse_obj({
            "block_type": obj.get("blockType"),
            "blocks": [
                    [BusinessProcessContentBlock.from_dict(_inner_item) for _inner_item in _item]
                    for _item in obj.get("blocks")
                ] if obj.get("blocks") is not None else None
        })
        return _obj

from helix_platform_api_public_client.models.business_process_content_block import BusinessProcessContentBlock
BusinessProcessForkBlock.update_forward_refs()




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.115
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List
from pydantic import BaseModel, Field, conlist
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_netted_nominations import ParticipantDashboardInterconnectorCapacityGraphDataMtusNettedNominations
from helix_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_values import ParticipantDashboardInterconnectorCapacityGraphDataMtusValues

class ParticipantDashboardInterconnectorCapacityGraphDataMtus(BaseModel):
    """
    ParticipantDashboardInterconnectorCapacityGraphDataMtus
    """
    mtu: datetime = Field(..., description="The first moment (inclusive) of an MTU period  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute MTU start point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format - only with `XX:00:00`, `XX:15:00`, `XX:30:00` and `XX:45:00` time parts are valid values (depending on MTU size) ")
    values: conlist(ParticipantDashboardInterconnectorCapacityGraphDataMtusValues) = Field(...)
    netted_nominations: ParticipantDashboardInterconnectorCapacityGraphDataMtusNettedNominations = Field(..., alias="nettedNominations")
    __properties = ["mtu", "values", "nettedNominations"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantDashboardInterconnectorCapacityGraphDataMtus:
        """Create an instance of ParticipantDashboardInterconnectorCapacityGraphDataMtus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in values (list)
        _items = []
        if self.values:
            for _item in self.values:
                if _item:
                    _items.append(_item.to_dict())
            _dict['values'] = _items
        # override the default output from pydantic by calling `to_dict()` of netted_nominations
        if self.netted_nominations:
            _dict['nettedNominations'] = self.netted_nominations.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantDashboardInterconnectorCapacityGraphDataMtus:
        """Create an instance of ParticipantDashboardInterconnectorCapacityGraphDataMtus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantDashboardInterconnectorCapacityGraphDataMtus.parse_obj(obj)

        _obj = ParticipantDashboardInterconnectorCapacityGraphDataMtus.parse_obj({
            "mtu": obj.get("mtu"),
            "values": [ParticipantDashboardInterconnectorCapacityGraphDataMtusValues.from_dict(_item) for _item in obj.get("values")] if obj.get("values") is not None else None,
            "netted_nominations": ParticipantDashboardInterconnectorCapacityGraphDataMtusNettedNominations.from_dict(obj.get("nettedNominations")) if obj.get("nettedNominations") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.115
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.timescale_nomination_options import TimescaleNominationOptions  # noqa: E501

class TestTimescaleNominationOptions(unittest.TestCase):
    """TimescaleNominationOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TimescaleNominationOptions:
        """Test TimescaleNominationOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TimescaleNominationOptions`
        """
        model = TimescaleNominationOptions()  # noqa: E501
        if include_optional:
            return TimescaleNominationOptions(
                window_timing = helix_platform_api_public_client.models.timescale_nomination_options_window_timing.TimescaleNominationOptions_windowTiming(
                    open_at = '2022-01-04T00:00Z', 
                    close_at = '2022-01-04T00:00Z', ),
                window_status = 'NOT_YET_OPEN',
                rights_in_directions = 'GB_FR'
            )
        else:
            return TimescaleNominationOptions(
                window_status = 'NOT_YET_OPEN',
                rights_in_directions = 'GB_FR',
        )
        """

    def testTimescaleNominationOptions(self):
        """Test TimescaleNominationOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
